amoniak
=======

AMON Library and utils to convert GISCE-ERP objects to AMON data


Working with environment variables
----------------------------------

To work with **Empowering services** you must define the following environment variables:

* EMPOWERING_COMPANY_ID
* EMPOWERING_KEY_FILE
* EMPOWERING_CERT_FILE (This can be the same as EMPOWERING_KEY_FILE)

If you want to work with empowering debug server you have to define EMPOWERING_DEBUG


Working with ERPPeek
--------------------

* PEEK_SERVER
* PEEK_DB
* PEEK_USER
* PEEK_PASSWORD


Working with MongoDB
--------------------

* MONGODB_HOST
* MONGODB_DATABASE


Working with Sentry
-------------------

* SENTRY_DSN

Be sure to use a synchronous protocol

